@@ -7,4 +7,4 @@
 #include "salalib/shapemap.h"
 #include "salalib/shapegraph.h"
 #include "salalib/alllinemap.h"
-#include "salalib/pointdata.h"
+#include "salalib/pointmap.h"
