@@ -11,8 +11,17 @@
 class SegmentTulipDepth : ISegment {
     int m_tulip_bins = 1024;
 
+    std::set<int> &m_originRefs;
+
   public:
+    struct Column {
+        inline static const std::string                //
+            ANGULAR_STEP_DEPTH = "Angular Step Depth"; //
+    };
+
+  public:
+    SegmentTulipDepth(int tulip_bins, std::set<int> &originRefs)
+        : m_tulip_bins(tulip_bins), m_originRefs(originRefs) {}
     std::string getAnalysisName() const override { return "Tulip Analysis"; }
-    SegmentTulipDepth(int tulip_bins) : m_tulip_bins(tulip_bins) {}
     AnalysisResult run(Communicator *, ShapeGraph &map, bool) override;
 };
