@@ -6,14 +6,28 @@
 
 #pragma once
 
+#include "salalib/isovist.h"
 #include "salalib/ivga.h"
-#include "salalib/pointdata.h"
+#include "salalib/pointmap.h"
 
 #include "genlib/bsptree.h"
 
 class VGAIsovist : IVGA {
     const std::vector<SalaShape> &m_boundaryShapes;
 
+  public:
+    struct Column {
+        inline static const std::string                          //
+            ISOVIST_AREA = "Isovist Area",                       //
+            ISOVIST_COMPACTNESS = "Isovist Compactness",         //
+            ISOVIST_DRIFT_ANGLE = "Isovist Drift Angle",         //
+            ISOVIST_DRIFT_MAGNITUDE = "Isovist Drift Magnitude", //
+            ISOVIST_MIN_RADIAL = "Isovist Min Radial",           //
+            ISOVIST_MAX_RADIAL = "Isovist Max Radial",           //
+            ISOVIST_OCCLUSIVITY = "Isovist Occlusivity",         //
+            ISOVIST_PERIMETER = "Isovist Perimeter";             //
+    };
+
   public:
     VGAIsovist(const std::vector<SalaShape> &boundaryShapes) : m_boundaryShapes(boundaryShapes) {}
     std::string getAnalysisName() const override { return "Isovist Analysis"; }
