@@ -7,12 +7,20 @@
 #pragma once
 
 #include "salalib/ivga.h"
-#include "salalib/pointdata.h"
+#include "salalib/pointmap.h"
 
 class VGAVisualLocal : IVGA {
   private:
     bool m_gates_only;
 
+  public:
+    struct Column {
+        inline static const std::string                                      //
+            VISUAL_CLUSTERING_COEFFICIENT = "Visual Clustering Coefficient", //
+            VISUAL_CONTROL = "Visual Control",                               //
+            VISUAL_CONTROLLABILITY = "Visual Controllability";               //
+    };
+
   public:
     std::string getAnalysisName() const override { return "Local Visibility Analysis"; }
     AnalysisResult run(Communicator *comm, PointMap &map, bool simple_version) override;
